Struct SysexMsg

pub struct SysexMsg { /* private fields */ }
Sysex messages can be of any length. To ensure no memory allocation, messages longer than SYSEXMSG_LEN will be split up in more than one SysexMsg.

Implementations

Source

impl SysexMsg

pub fn new_short(b: &[U7]) -> SysexMsg

pub fn encode<R, F: FnOnce(&[u8]) -> R>(&self, f: F) -> R

pub fn mmc_command<D: Into<U7>, C: Into<U7>>(device: D, command: C) -> SysexMsg