pub struct SysexMsg { /* private fields */ }Expand description
Sysex messages can be of any length. To ensure no memory allocation, messages longer than SYSEXMSG_LEN will be split up in more than one SysexMsg.
Implementations